@@ -46,6 +46,33 @@ module Mixlib
       Backend.info(options)
     end
 
+    #
+    # List available versions
+    #
+    # @return [Array<String>] list of available versions for the given
+    # product_name and channel.
+    def available_versions
+      self.class.available_versions(options.product_name, options.channel)
+    end
+
+    #
+    # List available versions
+    #
+    # @param [String] product name
+    #
+    # @param [String, Symbol] channel
+    #
+    # @return [Array<String>] list of available versions for the given
+    # product_name and channel.
+    def self.available_versions(product_name, channel)
+      Backend.available_versions(
+        Mixlib::Install::Options.new(
+          product_name: product_name,
+          channel: channel.to_sym
+        )
+      )
+    end
+
     #
     # Returns an install script for the given options
     #
@@ -55,6 +82,34 @@ module Mixlib
       Generator.install_command(options)
     end
 
+    #
+    # Download a single artifact
+    #
+    # @param [String] download directory. Default: Dir.pwd
+    #
+    # @return [String] file path of downloaded artifact
+    #
+    def download_artifact(directory = Dir.pwd)
+      if options.platform.nil? || options.platform_version.nil? || options.architecture.nil?
+        raise "Must provide platform options to download a specific artifact"
+      end
+
+      artifact = artifact_info
+
+      FileUtils.mkdir_p directory
+      file = File.join(directory, File.basename(artifact.url))
+
+      uri = URI.parse(artifact.url)
+      Net::HTTP.start(uri.host) do |http|
+        resp = http.get(uri.path)
+        open(file, "wb") do |io|
+          io.write(resp.body)
+        end
+      end
+
+      file
+    end
+
     #
     # Returns the base installation directory for the given options
     #
@@ -121,13 +176,17 @@ module Mixlib
                  # powershell.exe program with Mixlib::ShellOut
                  Dir.mktmpdir do |d|
                    File.open(File.join(d, "detect_platform.ps1"), "w+") do |f|
-                     f.puts self.detect_platform_ps1
+                     f.puts detect_platform_ps1
                    end
 
-                   Mixlib::ShellOut.new("powershell.exe -file #{File.join(d, "detect_platform.ps1")}").run_command
+                   # An update to most Windows versions > 2008r2 now sets the execution policy
+                   # to disallow unsigned powershell scripts. This changes it for just this
+                   # powershell session, which allows this to run even if the execution policy
+                   # is set higher.
+                   Mixlib::ShellOut.new("powershell.exe -file #{File.join(d, "detect_platform.ps1")}", :env => { "PSExecutionPolicyPreference" => "Bypass" }).run_command
                  end
                else
-                 Mixlib::ShellOut.new(self.detect_platform_sh).run_command
+                 Mixlib::ShellOut.new(detect_platform_sh).run_command
                end
 
       platform_info = output.stdout.split
