@@ -16,20 +16,21 @@
 # limitations under the License.
 #
 
-require "mixlib/install/backend/artifactory"
-require "mixlib/install/backend/bintray"
+require "mixlib/install/backend/package_router"
 
 module Mixlib
   class Install
     class Backend
-      def self.info(options)
-        backend = if options.for_artifactory?
-                    Backend::Artifactory.new(options)
-                  else
-                    Backend::Bintray.new(options)
-                  end
+      def self.available_versions(options)
+        backend(options).available_versions
+      end
 
-        backend.info
+      def self.info(options)
+        backend(options).info
+      end
+
+      def self.backend(options)
+        Backend::PackageRouter.new(options)
       end
     end
   end
